@@ -4,7 +4,7 @@ use strict;
 use warnings;
 package Alien::Sodium;
 our $AUTHORITY = 'cpan:AJGB';
-$Alien::Sodium::VERSION = '1.0.3.1';
+$Alien::Sodium::VERSION = '1.0.6.0';
 use parent 'Alien::Base';
 
 1;
@@ -21,7 +21,7 @@ Alien::Sodium - Install and make available libsodium library
 
 =head1 VERSION
 
-version 1.0.3.1
+version 1.0.6.0
 
 =head1 SYNOPSIS
 
@@ -32,7 +32,8 @@ version 1.0.3.1
 
 =head1 DESCRIPTION
 
-Alien::Sodium installs the C library C<libsodium> version 1.0.3 released on May 9, 2015.
+Alien::Sodium installs the C library C<libsodium> version 1.0.6 released on
+November 1, 2015.
 
 =head1 SEE ALSO
 
