@@ -45,17 +45,32 @@ crypto_sign_keypair(unsigned char *pk, unsigned char *sk)
 }
 
 int
-crypto_sign(unsigned char *sm, unsigned long long *smlen,
+crypto_sign(unsigned char *sm, unsigned long long *smlen_p,
             const unsigned char *m, unsigned long long mlen,
             const unsigned char *sk)
 {
-    return crypto_sign_ed25519(sm, smlen, m, mlen, sk);
+    return crypto_sign_ed25519(sm, smlen_p, m, mlen, sk);
 }
 
 int
-crypto_sign_open(unsigned char *m, unsigned long long *mlen,
+crypto_sign_open(unsigned char *m, unsigned long long *mlen_p,
                  const unsigned char *sm, unsigned long long smlen,
                  const unsigned char *pk)
 {
-    return crypto_sign_ed25519_open(m, mlen, sm, smlen, pk);
+    return crypto_sign_ed25519_open(m, mlen_p, sm, smlen, pk);
+}
+
+int
+crypto_sign_detached(unsigned char *sig, unsigned long long *siglen_p,
+                     const unsigned char *m, unsigned long long mlen,
+                     const unsigned char *sk)
+{
+    return crypto_sign_ed25519_detached(sig, siglen_p, m, mlen, sk);
+}
+
+int
+crypto_sign_verify_detached(const unsigned char *sig, const unsigned char *m,
+                            unsigned long long mlen, const unsigned char *pk)
+{
+    return crypto_sign_ed25519_verify_detached(sig, m, mlen, pk);
 }
