@@ -4,9 +4,6 @@
 #include <stddef.h>
 #include "export.h"
 
-#define crypto_shorthash_siphash24_BYTES 8U
-#define crypto_shorthash_siphash24_KEYBYTES 16U
-
 #ifdef __cplusplus
 # if __GNUC__
 #  pragma GCC diagnostic ignored "-Wlong-long"
@@ -14,19 +11,20 @@
 extern "C" {
 #endif
 
+#define crypto_shorthash_siphash24_BYTES 8U
 SODIUM_EXPORT
 size_t crypto_shorthash_siphash24_bytes(void);
 
+#define crypto_shorthash_siphash24_KEYBYTES 16U
 SODIUM_EXPORT
-const char * crypto_shorthash_siphash24_primitive(void);
+size_t crypto_shorthash_siphash24_keybytes(void);
 
 SODIUM_EXPORT
-int crypto_shorthash_siphash24(unsigned char *,const unsigned char *,unsigned long long,const unsigned char *);
+int crypto_shorthash_siphash24(unsigned char *out, const unsigned char *in,
+                               unsigned long long inlen, const unsigned char *k);
 
 #ifdef __cplusplus
 }
 #endif
 
-#define crypto_shorthash_siphash24_ref crypto_shorthash_siphash24
-
 #endif
