@@ -28,19 +28,16 @@ SODIUM_EXPORT
 size_t crypto_stream_salsa208_noncebytes(void);
 
 SODIUM_EXPORT
-const char * crypto_stream_salsa208_primitive(void);
+int crypto_stream_salsa208(unsigned char *c, unsigned long long clen,
+                           const unsigned char *n, const unsigned char *k);
 
 SODIUM_EXPORT
-int crypto_stream_salsa208(unsigned char *,unsigned long long,const unsigned char *,const unsigned char *);
-
-SODIUM_EXPORT
-int crypto_stream_salsa208_xor(unsigned char *,const unsigned char *,unsigned long long,const unsigned char *,const unsigned char *);
+int crypto_stream_salsa208_xor(unsigned char *c, const unsigned char *m,
+                               unsigned long long mlen, const unsigned char *n,
+                               const unsigned char *k);
 
 #ifdef __cplusplus
 }
 #endif
 
-#define crypto_stream_salsa208_ref crypto_stream_salsa208
-#define crypto_stream_salsa208_ref_xor crypto_stream_salsa208_xor
-
 #endif
