@@ -2,9 +2,22 @@
 #ifndef __CMPTEST_H__
 #define __CMPTEST_H__
 
+#include <assert.h>
 #include <stdio.h>
+#include <stdint.h>
+#include <stdlib.h>
+#include <string.h>
 
 #include "sodium.h"
+#include "quirks.h"
+
+#ifdef __EMSCRIPTEN__
+# undef TEST_SRCDIR
+# define TEST_SRCDIR "/test-data"
+#endif
+#ifndef TEST_SRCDIR
+# define TEST_SRCDIR "."
+#endif
 
 #define TEST_NAME_RES TEST_NAME ".res"
 #define TEST_NAME_OUT TEST_SRCDIR "/" TEST_NAME ".exp"
